@@ -91,89 +91,9 @@ function require_working_directory_clean(){
     true
   fi
 }
-function fix_wheel(){
-  # shellcheck disable=SC2155
-  local wheel=$( readlink -f "${1}")
-  if [ ! -f "$wheel" ]; then
-    echo "Wheel file $wheel does not exist!" 1>&2
-    return 1
-  fi
-  
-  # shellcheck disable=SC2155
-  local wheel_base=$(basename "$wheel")
-  local zip_base="${wheel_base/.whl/.zip}"
-  # shellcheck disable=SC2155
-  local workdir=$(mktemp -d)
-  local zipfile="${workdir}/${zip_base}"
-  echo "* Copying wheel to temporary directory."
-  if ! cp -v "${wheel}" "${zipfile}"; then
-    echo "Unable to copy wheel file." 1>&2
-    return 1
-  fi
-  echo "* Entering temporary directory."
-  if ! pushd "${workdir}" &> /dev/null; then
-    echo "Unable to enter temporary directory." 1>&2
-    return 1
-  fi
-  echo "* Extracting wheel zip file."
-  if ! unzip "${zipfile}"; then
-    echo "Unable to extract wheel contents." 1>&2
-    # shellcheck disable=SC2164
-    popd
-    return 1
-  fi
-  echo "* Finding and updating nspkg.pth files."
-  if ! find . -iname '*-nspkg.pth' -exec sed -i 's/;/\n/g' '{}' \;; then
-    echo "Can not modify nspkg.pth files." 1>&2
-    # shellcheck disable=SC2164
-    popd
-    return 1
-  fi
-  echo "* Removing the copied wheel archive."
-  if ! rm "${zipfile}"; then
-    echo "Unable to remove no-longer-needed zipfile." 1>&2
-    # shellcheck disable=SC2164
-    popd
-    return 1
-  fi
-  echo "* Zipping up fixed wheel contents."
-  if ! zip -r "${zip_base}" .; then
-    echo "Unable to archive fixed wheel contents." 1>&2
-    # shellcheck disable=SC2164
-    popd
-    return 1
-  fi
-  echo "* Copying fixed wheel zip file back to it's original location."
-  if ! cp -v "${zipfile}" "${wheel}" ; then
-    echo "Unable to copy the fixed wheel to it's original location." 1>&2
-    # shellcheck disable=SC2164
-    popd
-    return 1
-  fi
-  echo "* Removing the working directory."
-  if ! rm -rfv "${workdir}"; then
-    echo "Unable to remove temporary directory." 1>&2
-    # shellcheck disable=SC2164
-    popd
-    return 1
-  fi
-
-  # shellcheck disable=SC2164
-  popd
-  return 0
-}
 
 function do_action(){
   case "$1" in
-    fix-wheel)
-      shift
-      run "Fix wheel NSPKG.pth format." fix_wheel "$@"
-    ;;
-    fix-wheels)
-      for filename in dist/*.whl; do
-        do_action fix-wheel "$filename"
-      done
-    ;;
     rebuild-venv)
       local interpreter=${2-python3}
       run "Delete python3 environment." rm -rf "${VENV}"
@@ -229,7 +149,7 @@ function do_action(){
     coverage)
       shift
       activate_venv
-      run "Generate Coverage Data" pytest --cov-config=./.coveragerc --cov=pt.ptutils --cov-report html -vv --basetemp="${FOLDER}/src" "$@"
+      run "Generate Coverage Data" pytest --cov-config=./.coveragerc --cov=ptutils --cov-report html -vv --basetemp="${FOLDER}/ptutils" "$@"
     ;;
 
     docs)
@@ -253,24 +173,23 @@ function do_action(){
       fi
       rm ./op.log
       touch ./op.log
-      run --append "Compute Cyclomatic Complexity (CC)" radon cc -s -i '__pending*' ./src
-      run --append "Compute Maintainability Index (MI)" radon mi -s -i '__pending*' ./src
-      run --append "Compute raw statistics (RAW)" radon raw -s -i '__pending*' ./src
-      run --append "Analyze Code Quality" xenon -b C -m A -a A -i '__pending*' ./src
+      run --append "Compute Cyclomatic Complexity (CC)" radon cc -s -i '__pending*' ./ptutils
+      run --append "Compute Maintainability Index (MI)" radon mi -s -i '__pending*' ./ptutils
+      run --append "Compute raw statistics (RAW)" radon raw -s -i '__pending*' ./ptutils
+      run --append "Analyze Code Quality" xenon -b C -m A -a A -i '__pending*' ./ptutils
     ;;
 
     style)
       shift
       activate_venv
       export PYTHONUNBUFFERED=yes
-      run "Check Source code Style Compliance" flake8 --max-line-length=120 --ignore=E201,E202,E401,E221,E241,E251,W504 --exclude '__pending*' src
+      run "Check Source code Style Compliance" flake8 --max-line-length=120 --ignore=E201,E202,E401,E221,E241,E251,W504 --exclude '__pending*' ./ptutils
     ;;
     -h|--help|help)
       usage
     ;;
 
-    prerelease)
-      run "Ensure working directory is clean." require_working_directory_clean
+    prerelease-tests)
       do_action unit-test
       do_action coverage
       do_action quality --no-coverage
@@ -278,6 +197,11 @@ function do_action(){
       do_action docs --no-coverage
     ;;
 
+    prerelease)
+      run "Ensure working directory is clean." require_working_directory_clean
+      do_action prerelease-tests
+    ;;
+
     release-major)
       do_action prerelease
       run "Increment the version number (major)." bumpversion major
@@ -299,6 +223,14 @@ function do_action(){
       run "Push tags"    git push --tags
     ;;
 
+    clean)
+        run "Removing built files but preserving venv" git clean -xdf -e py3venv/ -e op.log
+    ;;
+
+    clean-all)
+        run "Removing built files and venv" git clean -xdf -e op.log
+    ;;
+
     *)
       errexit "Unknown action '$1'. Try '$0 --help' for more information."
     ;;
