@@ -343,7 +343,7 @@ class Program(object):  # pragma: no cover
         Start the child program.
         """
         if not self.silent:
-            logger.info("🟩 Starting program: %s" % self, data=self.env)
+            logger.info(f"🟩 Starting program: {self}\n environment = {self.env}")
 
         self._T_start = now()
 
